@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction;
-$XML::Grammar::Fiction::VERSION = '0.18.2';
+$XML::Grammar::Fiction::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -12,9 +12,14 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::Fiction - CPAN distribution implementing an XML grammar
+and a lightweight markup language for stories, novels and other fiction.
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
@@ -49,11 +54,6 @@ L<XML::Grammar::Screenplay> .
 
 The rest of this page will document the syntax of the custom textual format.
 
-=head1 NAME
-
-XML::Grammar::Fiction - CPAN distribution implementing an XML grammar
-and a lightweight markup language for stories, novels and other fiction.
-
 =head1 FORMAT
 
 =head2 Sections
@@ -201,7 +201,7 @@ so you'll need to accept that some modifications to your sources will be
 required in the future. I hope you still find it useful and let me know
 if you need any feature or bug-fix.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -238,14 +238,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
