@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::App::ToHTML;
-$XML::Grammar::Fiction::App::ToHTML::VERSION = '0.18.2';
+$XML::Grammar::Fiction::App::ToHTML::VERSION = '0.18.3';
 use strict;
 use warnings;
 use autodie;
@@ -48,27 +48,27 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::Fiction::App::ToHTML - command line app-in-a-module to convert
+Fiction-XML file to HTML
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
     perl -MXML::Grammar::Fiction::App::ToHTML -e 'run()' -- \
 	-o "$OUTPUT_FILE" "$INPUT_FILE"
 
-=head1 NAME
-
-XML::Grammar::Fiction::App::ToHTML - command line app-in-a-module to convert
-Fiction-XML file to HTML
-
 =head1 FUNCTIONS
 
 =head2 run()
 
 Call with no arguments to run the application from the commandline.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -105,14 +105,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
