@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::Err;
-$XML::Grammar::Fiction::Err::VERSION = '0.18.2';
+$XML::Grammar::Fiction::Err::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -48,9 +48,14 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::Fiction::Err - Exception::Class-based exceptions used by
+XML::Grammar::Fiction
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
@@ -69,12 +74,7 @@ version 0.18.2
 
 These are exceptions for L<XML::Grammar::Fiction> based on L<Exception::Class>
 
-=head1 NAME
-
-XML::Grammar::Fiction::Err - Exception::Class-based exceptions used by
-XML::Grammar::Fiction
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -111,14 +111,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
