@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node;
-$XML::Grammar::Fiction::FromProto::Node::VERSION = '0.18.2';
+$XML::Grammar::Fiction::FromProto::Node::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -24,20 +24,20 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
-=head1 DESCRIPTION
-
-Contains several nodes.
-
 =head1 NAME
 
 XML::Grammar::Fiction::FromProto::Node - contains several nodes for
 use in XML::Grammar::Fiction::FromProto.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=head1 VERSION
+
+version 0.18.3
+
+=head1 DESCRIPTION
+
+Contains several nodes.
+
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -74,14 +74,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
