@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Node::Comment;
-$XML::Grammar::Fiction::FromProto::Node::Comment::VERSION = '0.18.2';
+$XML::Grammar::Fiction::FromProto::Node::Comment::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -19,9 +19,9 @@ __END__
 
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -58,14 +58,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
