@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto::Parser;
-$XML::Grammar::Fiction::FromProto::Parser::VERSION = '0.18.2';
+$XML::Grammar::Fiction::FromProto::Parser::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -14,10 +14,6 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Fiction::FromProto::Parser - base class for parsers of the
@@ -25,7 +21,11 @@ Fiction-XML proto-text.
 
 B<For internal use only>.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=head1 VERSION
+
+version 0.18.3
+
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -62,14 +62,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
