@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::Struct::Tag;
-$XML::Grammar::Fiction::Struct::Tag::VERSION = '0.18.2';
+$XML::Grammar::Fiction::Struct::Tag::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -51,7 +51,7 @@ sub detach_children
 }
 
 package XML::Grammar::Fiction::Struct::Tag::Para;
-$XML::Grammar::Fiction::Struct::Tag::Para::VERSION = '0.18.2';
+$XML::Grammar::Fiction::Struct::Tag::Para::VERSION = '0.18.3';
 use MooX 'late';
 
 extends("XML::Grammar::Fiction::Struct::Tag");
@@ -65,10 +65,6 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Fiction::Struct::Tag - information about an XML/SGML opening or
@@ -76,6 +72,10 @@ closing tag.
 
 B<For internal use only>.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 METHODS
 
 =head2 $self->name()
@@ -110,7 +110,7 @@ Appends a single child. Uses C<append_children()> .
 
 Detaches the children and returns them as an array reference.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -147,14 +147,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
