@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::Event;
-$XML::Grammar::FictionBase::Event::VERSION = '0.18.2';
+$XML::Grammar::FictionBase::Event::VERSION = '0.18.3';
 
 use strict;
 use warnings;
@@ -44,16 +44,16 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::FictionBase::Event - a parser event.
 
 B<For internal use only>.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 SLOTS
 
 =head2 $event->elem()
@@ -91,7 +91,7 @@ Returns true if the $event 's type is either "open" or "close".
 
 Leftover from Moo.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -128,14 +128,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
