@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::LineIterator;
-$XML::Grammar::FictionBase::FromProto::Parser::LineIterator::VERSION = '0.18.2';
+$XML::Grammar::FictionBase::FromProto::Parser::LineIterator::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -241,9 +241,16 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::FictionBase::FromProto::Parser::LineIterator - line iterator base
+class for the parser.
+
+B<For internal use only>.
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
@@ -254,13 +261,6 @@ B<TODO:> write one.
 This is a line iterator that is useful to handle text (e.g: out of a file)
 and process it incrementally.
 
-=head1 NAME
-
-XML::Grammar::FictionBase::FromProto::Parser::LineIterator - line iterator base
-class for the parser.
-
-B<For internal use only>.
-
 =head1 METHODS
 
 =head2 $self->setup_text($multi_line_text)
@@ -374,7 +374,7 @@ Returns if the parser reached the end of the file.
 
 Leftover from Moo.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -411,14 +411,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
