@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::XmlIterator;
-$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.18.2';
+$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -917,9 +917,16 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::FictionBase::FromProto::Parser::XmlIterator - line iterator base
+class with some nested XMLisms.
+
+B<For internal use only>.
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
@@ -959,13 +966,6 @@ XML-like grammars.
 
 =end Removed
 
-=head1 NAME
-
-XML::Grammar::FictionBase::FromProto::Parser::XmlIterator - line iterator base
-class with some nested XMLisms.
-
-B<For internal use only>.
-
 =head1 METHODS
 
 =head2 $self->process_text($string)
@@ -976,7 +976,7 @@ Processes the text and returns the parse tree.
 
 Leftover from Moo.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -1013,14 +1013,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
