@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::XSLT::Converter;
-$XML::Grammar::FictionBase::XSLT::Converter::VERSION = '0.18.2';
+$XML::Grammar::FictionBase::XSLT::Converter::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -195,15 +195,15 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::FictionBase::XSLT::Converter - base module that converts an XML
 file to a different XML file using an XSLT transform.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 METHODS
 
 =head2 new()
@@ -248,7 +248,7 @@ The C<'output'> key specifies the return value. A value of C<'string'> returns
 the XML as a string, and a value of C<'dom'> returns the XML as an
 L<XML::LibXML> DOM object.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -285,14 +285,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
