@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay;
-$XML::Grammar::Screenplay::VERSION = '0.18.2';
+$XML::Grammar::Screenplay::VERSION = '0.18.3';
 use warnings;
 use strict;
 
@@ -12,9 +12,14 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+XML::Grammar::Screenplay - CPAN distribution implementing an XML grammar for
+screenplays.
+
 =head1 VERSION
 
-version 0.18.2
+version 0.18.3
 
 =head1 SYNOPSIS
 
@@ -42,11 +47,6 @@ command line applications for their processing.
 
 The rest of this page will document the syntax of the custom textual format.
 
-=head1 NAME
-
-XML::Grammar::Screenplay - CPAN distribution implementing an XML grammar for
-screenplays.
-
 =head1 FORMAT
 
 =head2 Scenes
@@ -184,7 +184,7 @@ L<http://www.shlomifish.org/humour/Summerschool-at-the-NSA/>
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -221,14 +221,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
