@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::App::ToDocBook;
-$XML::Grammar::Screenplay::App::ToDocBook::VERSION = '0.18.2';
+$XML::Grammar::Screenplay::App::ToDocBook::VERSION = '0.18.3';
 use strict;
 use warnings;
 use autodie;
@@ -48,22 +48,22 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Screenplay::App::ToDocBook - module implementing
 a command line application to convert a Screenplay XML file to docbook.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 FUNCTIONS
 
 =head2 run()
 
 Call with no arguments to run the application from the commandline.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -100,14 +100,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
