@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::Base;
-$XML::Grammar::Screenplay::Base::VERSION = '0.18.2';
+$XML::Grammar::Screenplay::Base::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -24,22 +24,22 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Screenplay::Base - base class for XML::Grammar::Screenplay
 classes.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 METHODS
 
 =head2 $package->new({%args});
 
 Constructs a new package
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -76,14 +76,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
