@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.18.2';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.18.3';
 use strict;
 use warnings;
 use autodie;
@@ -166,10 +166,6 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Screenplay::FromProto - module that converts well-formed
@@ -188,7 +184,11 @@ Internal - (to settle pod-coverage.).
 
 Converts the file $path_to_file to XML and returns it.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=head1 VERSION
+
+version 0.18.3
+
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -225,14 +225,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
