@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::Parser::QnD;
-$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.18.2';
+$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.18.3';
 use strict;
 use warnings;
 
@@ -601,10 +601,6 @@ __END__
 
 =encoding UTF-8
 
-=head1 VERSION
-
-version 0.18.2
-
 =head1 NAME
 
 XML::Grammar::Screenplay::FromProto::Parser::QnD - Quick and Dirty parser
@@ -612,6 +608,10 @@ for the Screenplay-XML proto-text.
 
 B<For internal use only>.
 
+=head1 VERSION
+
+version 0.18.3
+
 =head1 METHODS
 
 =head2 $self->process_text($string)
@@ -626,7 +626,7 @@ Leftover from Moo.
 
 Leftover from Moo.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -663,14 +663,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
